summaryrefslogtreecommitdiff
path: root/qadevOOo
diff options
context:
space:
mode:
authorRĂ¼diger Timm <rt@openoffice.org>2008-06-13 11:46:12 +0000
committerRĂ¼diger Timm <rt@openoffice.org>2008-06-13 11:46:12 +0000
commit4cafd752c81e313e7155e09899f081e60a05db56 (patch)
tree5763b98ad356e7e1902df72e67ec96e93e2dc42d /qadevOOo
parent3b106531b84021e3419ef838c26e95142a91a4bc (diff)
INTEGRATION: CWS qadev32 (1.12.2); FILE MERGED
2008/04/17 11:40:14 cn 1.12.2.3: RESYNC: (1.12-1.13); FILE MERGED 2008/04/17 07:58:14 cn 1.12.2.2: #i87389# enhance timeout 2008/03/04 19:57:07 cn 1.12.2.1: #i86692# change default connection method to named pipe: pipe,name=$USER
Diffstat (limited to 'qadevOOo')
-rw-r--r--qadevOOo/runner/lib/TestParameters.java10
1 files changed, 7 insertions, 3 deletions
diff --git a/qadevOOo/runner/lib/TestParameters.java b/qadevOOo/runner/lib/TestParameters.java
index ca621d3a79a9..66beb3bdd127 100644
--- a/qadevOOo/runner/lib/TestParameters.java
+++ b/qadevOOo/runner/lib/TestParameters.java
@@ -7,7 +7,7 @@
* OpenOffice.org - a multi-platform office productivity suite
*
* $RCSfile: TestParameters.java,v $
- * $Revision: 1.13 $
+ * $Revision: 1.14 $
*
* This file is part of OpenOffice.org.
*
@@ -170,9 +170,9 @@ public class TestParameters extends Hashtable {
/*
* This parameter contains the time which the office could use to close for
* itself before its destroyed. Default is 5000 ms
*/
- public Integer OfficeCloseTimeOut = new Integer(5000);
+ public Integer OfficeCloseTimeOut = new Integer(15000);
/**
* Wraper around "get()" with some debug output
@@ -256,6 +256,10 @@ public class TestParameters extends Hashtable {
*/
public TestParameters() {
//fill the propertyset
+ String user = System.getProperty("user.name");
+ if ( user != null) {
+ ConnectionString = "pipe,name=" + user;
+ }
put(PropertyName.CONNECTION_STRING,ConnectionString);
put(PropertyName.TEST_BASE,TestBase);
put(PropertyName.TEST_DOCUMENT_PATH,TestDocumentPath);
@@ -170,9 +170,9 @@ public class TestParameters extends Hashtable {
/*
* This parameter contains the time which the office could use to close for
- * itself before its destroyed. Default is 5000 ms
+ * itself before its destroyed. Default is 15000 ms
*/